@@ -12,6 +12,7 @@ class DelayHook(Storage):
     def __init__(self, storage):
         self.storage = storage
         self.reset()
+        signal_processor(self)
 
     def __nonzero__(self):
         return bool(self.storage)
@@ -57,6 +58,12 @@ class DelayHook(Storage):
     def get_avaiable_name(self, name):
         return self.storage.get_avaiable_name(name)
 
+    def get_valid_name(self, name):
+        return self.storage.get_valid_name(name)
+
+    def listdir(self, path):
+        return self.storage.listdir(path)
+
     def url(self, name):
         return self.storage.url(name)
 
